@@ -7,11 +7,11 @@
  *   linking, unlinking, and relaying to another bot
  *   pinging the bots periodically and checking leaf status
  *
- * $Id: botnet.c,v 1.52 2003/04/17 01:55:57 wcc Exp $
+ * $Id: botnet.c,v 1.55 2004/02/01 06:13:02 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -562,7 +562,7 @@ void tell_bots(int idx)
   }
   if (s[0])
     dprintf(idx, "Bots: %s\n", s);
-  dprintf(idx, "(%s: %d)\n", MISC_TOTAL, tands + 1);
+  dprintf(idx, "%s: %d\n", MISC_TOTAL, tands + 1);
 }
 
 /* Show a simpleton bot tree
@@ -1054,11 +1054,7 @@ static void botlink_resolve_success(int i)
   strcpy(dcc[i].u.bot->version, "(primitive bot)");
   dcc[i].u.bot->numver = idx;
   dcc[i].u.bot->port = dcc[i].port;     /* Remember where i started */
-#ifdef USE_IPV6
-  dcc[i].sock = getsock(SOCK_STRONGCONN, getprotocol(dcc[i].host));
-#else
   dcc[i].sock = getsock(SOCK_STRONGCONN);
-#endif /* USE_IPV6 */
   nfree(linker);
   if (dcc[i].sock < 0 ||
       open_telnet_raw(dcc[i].sock, iptostr(htonl(dcc[i].addr)),
@@ -1094,11 +1090,7 @@ static void failed_tandem_relay(int idx)
     return;
   }
   killsock(dcc[idx].sock);
-#ifdef USE_IPV6
-  dcc[idx].sock = getsock(SOCK_STRONGCONN, getprotocol(dcc[idx].host));
-#else
   dcc[idx].sock = getsock(SOCK_STRONGCONN);
-#endif /* USE_IPV6 */
   dcc[uidx].u.relay->sock = dcc[idx].sock;
   dcc[idx].port++;
   dcc[idx].timeval = now;
@@ -1144,11 +1136,7 @@ void tandem_relay(int idx, char *nick, register int i)
     return;
   }
 
-#ifdef USE_IPV6
-  dcc[i].sock = getsock(SOCK_STRONGCONN | SOCK_VIRTUAL, getprotocol(bi->address));
-#else
   dcc[i].sock = getsock(SOCK_STRONGCONN | SOCK_VIRTUAL);
-#endif /* USE_IPV6 */
   if (dcc[i].sock < 0) {
     lostdcc(i);
     dprintf(idx, "%s\n", MISC_NOFREESOCK);
