@@ -5,11 +5,11 @@
  *   command line arguments
  *   context and assert debugging
  *
- * $Id: main.c,v 1.97 2003/04/17 01:55:57 wcc Exp $
+ * $Id: main.c,v 1.107 2004/05/26 00:20:19 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,29 +32,28 @@
  */
 
 #include "main.h"
+
 #include <fcntl.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
 #include <errno.h>
 #include <signal.h>
 #include <netdb.h>
 #include <setjmp.h>
 
-#ifdef STOP_UAC                 /* osf/1 complains a lot */
-#include <sys/sysinfo.h>
-#define UAC_NOPRINT    0x00000001       /* Don't report unaligned fixups */
+#ifdef TIME_WITH_SYS_TIME
+#  include <sys/time.h>
+#  include <time.h>
+#else
+#  ifdef HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#  else
+#    include <time.h>
+#  endif
+#endif
+
+#ifdef STOP_UAC                         /* osf/1 complains a lot */
+#  include <sys/sysinfo.h>
+#  define UAC_NOPRINT 0x00000001        /* Don't report unaligned fixups */
 #endif
-/* Some systems have a working sys/wait.h even though configure will
- * decide it's not bsd compatable.  Oh well.
- */
 
 #include "chan.h"
 #include "modules.h"
@@ -62,12 +61,11 @@
 #include "bg.h"
 
 #ifdef CYGWIN_HACKS
-#include <windows.h>
+#  include <windows.h>
 #endif
 
 #ifndef _POSIX_SOURCE
-/* Solaris needs this */
-#define _POSIX_SOURCE 1
+#  define _POSIX_SOURCE 1 /* Solaris needs this */
 #endif
 
 extern char origbotname[], userfile[], botnetnick[];
@@ -79,7 +77,7 @@ extern log_t *logs;
 extern Tcl_Interp *interp;
 extern tcl_timer_t *timer, *utimer;
 extern jmp_buf alarmret;
-
+time_t now;
 
 /*
  * Please use the PATCH macro instead of directly altering the version
@@ -88,49 +86,46 @@ extern jmp_buf alarmret;
  * modified versions of this bot.
  */
 
-char egg_version[1024] = "1.6.14";
-int egg_numver = 1061400;
+char egg_version[1024] = "1.6.16";
+int egg_numver = 1061600;
 
 char notify_new[121] = "";      /* Person to send a note to for new users */
-int default_flags = 0;          /* Default user flags and */
-int default_uflags = 0;         /* Default userdefinied flags for people
-                                 * who say 'hello' or for .adduser */
+int default_flags = 0;          /* Default user flags                     */
+int default_uflags = 0;         /* Default user-definied flags            */
 
-int backgrd = 1;                /* Run in the background? */
-int con_chan = 0;               /* Foreground: constantly display channel
-                                 * stats? */
-int term_z = 0;                 /* Foreground: use the terminal as a party
-                                 * line? */
-char configfile[121] = "eggdrop.conf";  /* Name of the config file */
-char helpdir[121] = "help/";    /* Directory of help files (if used) */
-char textdir[121] = "text/";    /* Directory for text files that get dumped */
-int keep_all_logs = 0;          /* Never erase logfiles, no matter how old
-                                 * they are? */
-char logfile_suffix[21] = ".%d%b%Y";    /* Format of logfile suffix. */
-time_t online_since;            /* Unix-time that the bot loaded up */
-int make_userfile = 0;          /* Using bot in make-userfile mode? (first
-                                 * user to 'hello' becomes master) */
-char owner[121] = "";           /* Permanent owner(s) of the bot */
-char pid_file[120];             /* Name of the file for the pid to be
-                                 * stored in */
-int save_users_at = 0;          /* How many minutes past the hour to
-                                 * save the userfile? */
-int notify_users_at = 0;        /* How many minutes past the hour to
-                                 * notify users of notes? */
-int switch_logfiles_at = 300;   /* When (military time) to switch logfiles */
-char version[81];               /* Version info (long form) */
-char ver[41];                   /* Version info (short form) */
-char egg_xtra[2048];            /* Patch info */
-int use_stderr = 1;             /* Send stuff to stderr instead of logfiles? */
-int do_restart = 0;             /* .restart has been called, restart asap */
-int die_on_sighup = 0;          /* die if bot receives SIGHUP */
-int die_on_sigterm = 1;         /* die if bot receives SIGTERM */
-int resolve_timeout = 15;       /* hostname/address lookup timeout */
-char quit_msg[1024];            /* quit message */
-time_t now;                     /* duh, now :) */
+int backgrd = 1;        /* Run in the background?                        */
+int con_chan = 0;       /* Foreground: constantly display channel stats? */
+int term_z = 0;         /* Foreground: use the terminal as a partyline?  */
+int use_stderr = 1;     /* Send stuff to stderr instead of logfiles?     */
 
-/* Traffic stats
- */
+char configfile[121] = "eggdrop.conf";  /* Default config file name */
+char pid_file[120];                     /* Name of the pid file     */
+char helpdir[121] = "help/";            /* Directory of help files  */
+char textdir[121] = "text/";            /* Directory for text files */
+
+int keep_all_logs = 0;                  /* Never erase logfiles?    */
+char logfile_suffix[21] = ".%d%b%Y";    /* Format of logfile suffix */
+int switch_logfiles_at = 300;           /* When to switch logfiles  */
+
+time_t online_since;    /* time that the bot was started */
+
+int make_userfile = 0; /* Using bot in userfile-creation mode? */
+char owner[121] = "";  /* Permanent owner(s) of the bot        */
+
+int save_users_at = 0;   /* Minutes past the hour to save the userfile?     */
+int notify_users_at = 0; /* Minutes past the hour to notify users of notes? */
+
+char version[81];    /* Version info (long form)  */
+char ver[41];        /* Version info (short form) */
+char egg_xtra[2048]; /* Patch info                */
+
+int do_restart = 0;       /* .restart has been called, restart ASAP */
+int die_on_sighup = 0;    /* Die if bot receives SIGHUP             */
+int die_on_sigterm = 1;   /* Die if bot receives SIGTERM            */
+int resolve_timeout = 15; /* Hostname/address lookup timeout        */
+char quit_msg[1024];      /* Quit message                           */
+
+/* Traffic stats */
 unsigned long otraffic_irc = 0;
 unsigned long otraffic_irc_today = 0;
 unsigned long otraffic_bn = 0;
@@ -179,7 +174,6 @@ void fatal(const char *s, int recoverable)
   }
 }
 
-
 int expmem_chanprog();
 int expmem_users();
 int expmem_misc();
@@ -241,11 +235,7 @@ void write_debug()
      *       _not_ safe <cybah>
      */
     x = creat("DEBUG.DEBUG", 0644);
-#ifdef USE_IPV6
-    setsock(x, SOCK_NONSOCK, AF_INET);
-#else
     setsock(x, SOCK_NONSOCK);
-#endif /* USE_IPV6 */
     if (x >= 0) {
       strncpyz(s, ctime(&now), sizeof s);
       dprintf(-x, "Debug (%s) written %s\n", ver, s);
@@ -270,11 +260,7 @@ void write_debug()
   putlog(LOG_MISC, "*", "* Please REPORT this BUG!");
   putlog(LOG_MISC, "*", "* Check doc/BUG-REPORT on how to do so.");
   x = creat("DEBUG", 0644);
-#ifdef USE_IPV6
-  setsock(x, SOCK_NONSOCK, AF_INET);
-#else
   setsock(x, SOCK_NONSOCK);
-#endif /* USE_IPV6 */
   if (x < 0) {
     putlog(LOG_MISC, "*", "* Failed to write DEBUG");
   } else {
@@ -721,12 +707,12 @@ int main(int argc, char **argv)
   struct sigaction sv;
   struct chanset_t *chan;
 
-#ifdef DEBUG_MEM
+#ifndef ENABLE_STRIP
+#include <sys/resource.h>
   /* Make sure it can write core, if you make debug. Else it's pretty
    * useless (dw)
    */
   {
-#include <sys/resource.h>
     struct rlimit cdlim;
 
     cdlim.rlim_cur = RLIM_INFINITY;
@@ -743,7 +729,7 @@ int main(int argc, char **argv)
   /* Version info! */
   egg_snprintf(ver, sizeof ver, "eggdrop v%s", egg_version);
   egg_snprintf(version, sizeof version,
-               "Eggdrop v%s (C) 1997 Robey Pointer (C) 2003 Eggheads",
+               "Eggdrop v%s (C) 1997 Robey Pointer (C) 2004 Eggheads",
                egg_version);
   /* Now add on the patchlevel (for Tcl) */
   sprintf(&egg_version[strlen(egg_version)], " %u", egg_numver);
@@ -792,7 +778,7 @@ int main(int argc, char **argv)
   chanset = NULL;
   egg_memcpy(&nowtm, localtime(&now), sizeof(struct tm));
   lastmin = nowtm.tm_min;
-  srandom(now % (getpid() + getppid()));
+  srandom((unsigned int) (now % (getpid() + getppid())));
   init_mem();
   init_language(1);
   if (argc > 1)
@@ -914,11 +900,7 @@ int main(int argc, char **argv)
       userlist = adduser(userlist, "HQ", "none", "-", USER_PARTY);
       dcc[n].user = get_user_by_handle(userlist, "HQ");
     }
-#ifdef USE_IPV6
-    setsock(STDOUT, 0, AF_INET); /* Entry in net table */
-#else
     setsock(STDOUT, 0);          /* Entry in net table */
-#endif /* USE_IPV6 */
     dprintf(n, "\n### ENTERING DCC CHAT SIMULATION ###\n\n");
     dcc_chatter(n);
   }
