@@ -2,11 +2,11 @@
  * files.c - part of filesys.mod
  *   handles all file system commands
  *
- * $Id: files.c,v 1.44 2003/03/16 21:41:29 wcc Exp $
+ * $Id: files.c,v 1.48 2004/01/09 05:56:38 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1174,7 +1174,8 @@ static void cmd_mv_cp(int idx, char *par, int copy)
   }
 
   filedb_readtop(fdb_old, NULL);
-  fdbe_old = filedb_matchfile(fdb_old, ftell(fdb_old), fn);
+  where = ftell(fdb_old);
+  fdbe_old = filedb_matchfile(fdb_old, where, fn);
   if (!fdbe_old) {
     if (fdb_new != fdb_old)
       filedb_close(fdb_new);
@@ -1184,6 +1185,27 @@ static void cmd_mv_cp(int idx, char *par, int copy)
     my_free(newfn);
     return;
   }
+
+  if (only_first) {
+    /* If the source file contains a wildcard and the dest is not a dir,
+     * then we check for multiple source files and if they are there,
+     * abort. Otherwise, proceed. */
+    filedb_entry *check_for_more;
+    check_for_more = filedb_matchfile(fdb_old, ftell(fdb_old), fn);
+    if (check_for_more) {
+      dprintf(idx, FILES_ILLDEST);
+      free_fdbe(&fdbe_old);
+      free_fdbe(&check_for_more);
+      if (fdb_new != fdb_old) filedb_close(fdb_new);
+      filedb_close(fdb_old);
+      my_free(oldpath);
+      my_free(newpath);
+      my_free(newfn);
+      return;
+    }
+    fseek(fdb_old, where, SEEK_SET);
+  }
+
   while (fdbe_old) {
     where = ftell(fdb_old);
     skip_this = 0;
