@@ -1,11 +1,11 @@
 /*
  * servmsg.c -- part of server.mod
  *
- * $Id: servmsg.c,v 1.79 2003/04/17 01:55:57 wcc Exp $
+ * $Id: servmsg.c,v 1.82 2004/05/26 00:20:19 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,7 +78,7 @@ static int gotfake433(char *from)
     } else {
       p++;
       if (!*p)
-        altnick_char = 'a' + random() % 26;
+        altnick_char = 'a' + randint(26);
       else
         altnick_char = (*p);
     }
@@ -1202,11 +1202,7 @@ static void connect_server(void)
     /* I'm resolving... don't start another server connect request */
     resolvserv = 1;
     /* Resolve the hostname. */
-#ifdef USE_IPV6
-    server_resolve_success(servidx);
-#else
     dcc_dnsipbyhost(dcc[servidx].host);
-#endif /* USE_IPV6 */
   }
 }
 
@@ -1228,11 +1224,7 @@ static void server_resolve_success(int servidx)
   dcc[servidx].addr = dcc[servidx].u.dns->ip;
   strcpy(pass, dcc[servidx].u.dns->cbuf);
   changeover_dcc(servidx, &SERVER_SOCKET, 0);
-#ifdef USE_IPV6
-  serv = open_telnet(dcc[servidx].host, dcc[servidx].port);
-#else
   serv = open_telnet(iptostr(htonl(dcc[servidx].addr)), dcc[servidx].port);
-#endif /* USE_IPV6 */
   if (serv < 0) {
     neterror(s);
     putlog(LOG_SERV, "*", "%s %s (%s)", IRC_FAILEDCONNECT, dcc[servidx].host,
