@@ -2,7 +2,7 @@
  * net.c -- handles:
  *   all raw network i/o
  *
- * $Id: net.c,v 1.59 2003/04/30 03:47:46 wcc Exp $
+ * $Id: net.c,v 1.67 2004/05/27 05:33:40 wcc Exp $
  */
 /*
  * This is hereby released into the public domain.
@@ -40,30 +40,18 @@ extern unsigned long otraffic_irc_today, otraffic_bn_today, otraffic_dcc_today,
                      otraffic_filesys_today, otraffic_trans_today,
                      otraffic_unknown_today;
 
-char hostname[121] = "";      /* Hostname can be specified in the config file */
-char myip[121] = "";          /* IP can be specified in the config file       */
+char hostname[121] = "";      /* Hostname can be specified in the config file.*/
+char myip[121] = "";          /* IP can be specified in the config file.      */
+char firewall[121] = "";      /* Socks server for firewall.                   */
+int firewallport = 1080;      /* Default port of socks 4/5 firewalls.         */
+char botuser[21] = "eggdrop"; /* Username of the user running the bot.        */
+int dcc_sanitycheck = 0;      /* Do some sanity checking on dcc connections.  */
 
-#ifdef USE_IPV6
-char myip6[121] = "";         /* IP can be specified in the config file       */
-char hostname6[121] = "";     /* Hostname can be specified in the config file */
-#endif /* USE_IPV6 */
-
-char firewall[121] = "";      /* Socks server for firewall                    */
-int firewallport = 1080;      /* Default port of Sock4/5 firewalls            */
-char botuser[21] = "eggdrop"; /* Username of the user running the bot         */
-int dcc_sanitycheck = 0;      /* We should do some sanity checking on dcc
-                               * connections.                                 */
-sock_list *socklist = NULL;   /* Enough to be safe                            */
+sock_list *socklist = NULL;   /* Enough to be safe.                           */
 int MAXSOCKS = 0;
-jmp_buf alarmret;             /* Env buffer for alarm() returns               */
+jmp_buf alarmret;             /* Env buffer for alarm() returns.              */
 
-#ifdef USE_IPV6
-struct hostent *myipv6he;
-char myipv6host[120];
-unsigned long notalloc = 0;
-#endif /* USE_IPV6 */
-
-/* Types of proxy */
+/* Types of proxies */
 #define PROXY_SOCKS   1
 #define PROXY_SUN     2
 
@@ -82,33 +70,6 @@ IP my_atoul(char *s)
   return ret;
 }
 
-int getprotocol(char *host)
-{
-#ifdef USE_IPV6
-  struct hostent *he;
-#  ifndef HAVE_GETHOSTBYNAME2
-  int error_num;
-#  endif /* !HAVE_GETHOSTBYNAME2 */
-
-  if (!setjmp(alarmret)) {
-    alarm(resolve_timeout);
-
-#  ifdef HAVE_GETHOSTBYNAME2
-    he = gethostbyname2(host, AF_INET6);
-#  else
-    he = getipnodebyname(host, AF_INET6, AI_DEFAULT, &error_num);
-#  endif /* HAVE_GETHOSTBYNAME2 */
-    alarm(0);
-  } else
-    he = NULL;
-  if (!he)
-    return AF_INET;
-  return AF_INET6;
-#else
-  return 0;
-#endif /* USE_IPV6 */
-}
-
 /* Initialize the socklist
  */
 void init_net()
@@ -143,30 +104,6 @@ IP getmyip()
   char s[121];
   IP ip;
   struct in_addr *in;
-#if defined(USE_IPV6) && !defined(HAVE_GETHOSTBYNAME2)
-  int error_num;
-#endif /* USE_IPV6 && !HAVE_GETHOSTBYNAME2 */
-
-#ifdef USE_IPV6
-  myipv6he = NULL;
-  /* Could be pre-defined */
-  if (myip6[0]) {
-#  ifdef HAVE_GETHOSTBYNAME2
-    myipv6he = gethostbyname2(myip6, AF_INET6);
-#  else
-    myipv6he = getipnodebyname(myip6, AF_INET6, AI_DEFAULT, &error_num);
-#  endif /* !HAVE_GETHOSTBYNAME2 */
-    if (myipv6he == NULL)
-      fatal("Hostname IPV6 self-lookup failed.", 0);
-  }
-  if (hostname6[0]) {
-    myipv6he = gethostbyname2(hostname6, AF_INET6);
-    if (myipv6he == NULL)
-      fatal("Hostname IPV6 self-lookup failed.", 0);
-  }
-  if (myipv6he != NULL)
-    egg_inet_ntop(AF_INET6, &myipv6he, myipv6host, 119);
-#endif /* USE_IPV6 */
   if (myip[0]) {
     if ((myip[strlen(myip) - 1] >= '0') && (myip[strlen(myip) - 1] <= '9'))
       return (IP) inet_addr(myip);
@@ -178,17 +115,9 @@ IP getmyip()
     gethostname(s, 120);
     hp = gethostbyname(s);
   }
-#ifdef USE_IPV6
-  if (hp == NULL && myipv6he == NULL)
-#else
   if (hp == NULL)
-#endif /* USE_IPV6 */
     fatal("Hostname self-lookup failed. Please set 'my-ip' in the config "
           "file.", 0);
-#ifdef USE_IPV6
-  if(hp == NULL)
-    return 0;
-#endif /* USE_IPV6 */
   in = (struct in_addr *) (hp->h_addr_list[0]);
   ip = (IP) (in->s_addr);
   return ip;
@@ -297,11 +226,7 @@ int sockoptions(int sock, int operation, int sock_options)
 
 /* Return a free entry in the socket entry
  */
-#ifdef USE_IPV6
-int allocsock(int sock, int options, int af_ty)
-#else
 int allocsock(int sock, int options)
-#endif /* USE_IPV6 */
 {
   int i;
 
@@ -312,9 +237,6 @@ int allocsock(int sock, int options)
       socklist[i].inbuflen = socklist[i].outbuflen = 0;
       socklist[i].flags = options;
       socklist[i].sock = sock;
-#ifdef USE_IPV6
-      socklist[i].af = af_ty;
-#endif /* USE_IPV6 */
       return i;
     }
   }
@@ -324,15 +246,9 @@ int allocsock(int sock, int options)
 
 /* Request a normal socket for i/o
  */
-#ifdef USE_IPV6
-void setsock(int sock, int options, int af_ty)
-{
-  int i = allocsock(sock, options, af_ty), parm;
-#else
 void setsock(int sock, int options)
 {
   int i = allocsock(sock, options), parm;
-#endif /* USE_IPV6 */
 
   if (((sock != STDOUT) || backgrd) && !(socklist[i].flags & SOCK_NONSOCK)) {
     parm = 1;
@@ -350,22 +266,12 @@ void setsock(int sock, int options)
   fcntl(sock, F_SETFL, O_NONBLOCK);
 }
 
-#ifdef USE_IPV6
-int getsock(int options, int af_def)
-{
-  int sock = socket(af_def, SOCK_STREAM, 0);
-#else
 int getsock(int options)
 {
   int sock = socket(AF_INET, SOCK_STREAM, 0);
-#endif /* USE_IPV6 */
 
   if (sock >= 0)
-#ifdef USE_IPV6
-    setsock(sock, options, af_def);
-#else
     setsock(sock, options);
-#endif /* USE_IPV6 */
   else
     putlog(LOG_MISC, "*", "Warning: Can't create new socket!");
   return sock;
@@ -403,42 +309,23 @@ void killsock(register int sock)
  */
 static int proxy_connect(int sock, char *host, int port, int proxy)
 {
-#ifdef USE_IPV6
-  unsigned char x[32];
-  int af_ty;
-#else
   unsigned char x[10];
-#endif /* USE_IPV6 */
   struct hostent *hp;
   char s[256];
   int i;
 
-#ifdef USE_IPV6
-  af_ty = getprotocol(host);
-#endif /* USE_IPV6 */
   /* socks proxy */
   if (proxy == PROXY_SOCKS) {
     /* numeric IP? */
-#ifdef USE_IPV6
-    if ((host[strlen(host) - 1] >= '0' && host[strlen(host) - 1] <= '9') && af_ty != AF_INET6) {
-#else
     if (host[strlen(host) - 1] >= '0' && host[strlen(host) - 1] <= '9') {
-#endif /* USE_IPV6 */
       IP ip = ((IP) inet_addr(host));
       egg_memcpy(x, &ip, 4);
     } else {
       /* no, must be host.domain */
       if (!setjmp(alarmret)) {
-#ifdef USE_IPV6
         alarm(resolve_timeout);
-        if (af_ty == AF_INET6)
-          hp = gethostbyname(host);
-        else
-#endif /* USE_IPV6 */
-          hp = gethostbyname(host);
-#ifdef USE_IPV6
+        hp = gethostbyname(host);
         alarm(0);
-#endif /* USE_IPV6 */
       } else
         hp = NULL;
       if (hp == NULL) {
@@ -450,15 +337,6 @@ static int proxy_connect(int sock, char *host, int port, int proxy)
     for (i = 0; i < MAXSOCKS; i++)
       if (!(socklist[i].flags & SOCK_UNUSED) && socklist[i].sock == sock)
         socklist[i].flags |= SOCK_PROXYWAIT;    /* drummer */
-#ifdef USE_IPV6
-    if (af_ty == AF_INET6)
-      egg_snprintf(s, sizeof s,
-                   "\004\001%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%s",
-                   (port >> 8) % 256, (port % 256), x[0], x[1], x[2], x[3],
-                   x[4], x[5], x[6], x[7], x[9], x[9], x[10], x[11],  x[12],
-                   x[13], x[14], x[15], botuser);
-    else
-#endif /* USE_IPV6 */
       egg_snprintf(s, sizeof s, "\004\001%c%c%c%c%c%c%s", (port >> 8) % 256,
                    (port % 256), x[0], x[1], x[2], x[3], botuser);
     tputs(sock, s, strlen(botuser) + 9);        /* drummer */
@@ -469,24 +347,6 @@ static int proxy_connect(int sock, char *host, int port, int proxy)
   return sock;
 }
 
-
-/* Return protocol of socket
- */
-int getsockproto(int sock)
-{
-#ifdef USE_IPV6
-  int i;
-  for (i = 0; i < MAXSOCKS; i++) {
-    if (socklist[i].sock == sock)
-      return socklist[i].af;
-  }
-  return AF_INET;
-#else
-  return 0;
-#endif /* USE_IPV6 */
-}
-
-
 /* Starts a connection attempt to a socket
  *
  * If given a normal hostname, this will be resolved to the corresponding
@@ -500,14 +360,6 @@ int getsockproto(int sock)
 int open_telnet_raw(int sock, char *server, int sport)
 {
   struct sockaddr_in name;
-#ifdef USE_IPV6
-  struct sockaddr_in6 name6;
-  unsigned long succ;
-  int af_ty;
-#  ifndef HAVE_GETHOSTBYNAME2
-  int error_num;
-#  endif /* !HAVE_GETHOSTBYNAME2 */
-#endif /* USE_IPV6 */
   struct hostent *hp;
   char host[121];
   int i, port, rc;
@@ -528,94 +380,44 @@ int open_telnet_raw(int sock, char *server, int sport)
     strcpy(host, server);
     port = sport;
   }
-#ifdef USE_IPV6
-  af_ty = getprotocol(host);
-  if (af_ty == AF_INET6) {
-    succ = getmyip();
-    bzero((char *) &name6, sizeof(struct sockaddr_in6));
+  egg_bzero((char *) &name, sizeof(struct sockaddr_in));
 
-    name6.sin6_family = AF_INET6;
-    if (myip6[0]) {
-      if (myipv6he == NULL)
-        memcpy(&name6.sin6_addr, &in6addr_any, 16);
-      else
-        memcpy(&name6.sin6_addr, myipv6he->h_addr, myipv6he->h_length);
-    }
-    if (bind(sock, (struct sockaddr *) &name6, sizeof(name6)) < 0) {
-      killsock(sock);
-      return -1;
-    }
-    bzero((char *) &name6, sizeof(struct sockaddr_in6));
-    name6.sin6_family = AF_INET6;
-    name6.sin6_port = htons(port);
+  name.sin_family = AF_INET;
+  name.sin_addr.s_addr = (myip[0] ? getmyip() : INADDR_ANY);
+  if (bind(sock, (struct sockaddr *) &name, sizeof(name)) < 0)
+    return -1;
+  egg_bzero((char *) &name, sizeof(struct sockaddr_in));
+
+  name.sin_family = AF_INET;
+  name.sin_port = htons(port);
+  /* Numeric IP? */
+  if ((host[strlen(host) - 1] >= '0') && (host[strlen(host) - 1] <= '9'))
+    name.sin_addr.s_addr = inet_addr(host);
+  else {
+    /* No, must be host.domain */
+    debug0("WARNING: open_telnet_raw() is about to block in gethostbyname()!");
     if (!setjmp(alarmret)) {
       alarm(resolve_timeout);
-#  ifdef HAVE_GETHOSTBYNAME2
-      hp = gethostbyname2(host, AF_INET6);
-#  else
-      hp = getipnodebyname(host, AF_INET6, AI_DEFAULT, &error_num);
-#  endif /* HAVE_GETHOSTBYNAME2 */
+      hp = gethostbyname(host);
       alarm(0);
     } else
       hp = NULL;
-    if (hp == NULL) {
-      killsock(sock);
+    if (hp == NULL)
       return -2;
-    }
-    egg_memcpy((char *) &name6.sin6_addr, hp->h_addr, hp->h_length);
-    name6.sin6_family = hp->h_addrtype;
-#  ifndef HAVE_GETHOSTBYNAME2
-    freehostent(myipv6he);
-#  endif /* !HAVE_GETHOSTBYNAME2 */
-  } else {
-#endif /* USE_IPV6 */
-    egg_bzero((char *) &name, sizeof(struct sockaddr_in));
-
-    name.sin_family = AF_INET;
-    name.sin_addr.s_addr = (myip[0] ? getmyip() : INADDR_ANY);
-    if (bind(sock, (struct sockaddr *) &name, sizeof(name)) < 0)
-      return -1;
-    egg_bzero((char *) &name, sizeof(struct sockaddr_in));
-
-    name.sin_family = AF_INET;
-    name.sin_port = htons(port);
-    /* Numeric IP? */
-    if ((host[strlen(host) - 1] >= '0') && (host[strlen(host) - 1] <= '9'))
-      name.sin_addr.s_addr = inet_addr(host);
-    else {
-      /* No, must be host.domain */
-      debug0("WARNING: open_telnet_raw() is about to block in gethostbyname()!");
-      if (!setjmp(alarmret)) {
-        alarm(resolve_timeout);
-        hp = gethostbyname(host);
-        alarm(0);
-      } else
-        hp = NULL;
-      if (hp == NULL)
-        return -2;
-      egg_memcpy(&name.sin_addr, hp->h_addr, hp->h_length);
-      name.sin_family = hp->h_addrtype;
-    }
-#ifdef USE_IPV6
+    egg_memcpy(&name.sin_addr, hp->h_addr, hp->h_length);
+    name.sin_family = hp->h_addrtype;
   }
-#endif /* USE_IPV6 */
   for (i = 0; i < MAXSOCKS; i++) {
     if (!(socklist[i].flags & SOCK_UNUSED) && (socklist[i].sock == sock))
       socklist[i].flags = (socklist[i].flags & ~SOCK_VIRTUAL) | SOCK_CONNECT;
   }
-#ifdef USE_IPV6
-  if(af_ty == AF_INET6)
-    rc = connect(sock, (struct sockaddr *) &name6,
-                 sizeof(struct sockaddr_in6));
-  else
-#endif /* USE_IPV6 */
-    rc = connect(sock, (struct sockaddr *) &name,
-                 sizeof(struct sockaddr_in));
-  if (rc < 0) {    if (errno == EINPROGRESS) {
+  rc = connect(sock, (struct sockaddr *) &name, sizeof(struct sockaddr_in));
+  if (rc < 0) {
+    if (errno == EINPROGRESS) {
       /* Firewall?  announce connect attempt to proxy */
       if (firewall[0])
         return proxy_connect(sock, server, sport, proxy);
-      return sock;              /* async success! */
+      return sock; /* async success! */
     } else
       return -1;
   }
@@ -628,11 +430,7 @@ int open_telnet_raw(int sock, char *server, int sport)
 /* Ordinary non-binary connection attempt */
 int open_telnet(char *server, int port)
 {
-#ifdef USE_IPV6
-  int sock = getsock(0, getprotocol(server)), ret = open_telnet_raw(sock, server, port);
-#else
   int sock = getsock(0), ret = open_telnet_raw(sock, server, port);
-#endif /* USE_IPV6 */
 
   if (ret < 0)
     killsock(sock);
@@ -641,21 +439,11 @@ int open_telnet(char *server, int port)
 
 /* Returns a socket number for a listening socket that will accept any
  * connection on a certain address -- port # is returned in port
- *
- * 'addr' is ignored if af_def is AF_INET6 -poptix (02/03/03)
  */
-#ifdef USE_IPV6
-int open_address_listen(IP addr, int af_def, int *port)
-#else
 int open_address_listen(IP addr, int *port)
-#endif /* USE_IPV6 */
  {
   int sock = 0;
-  unsigned int addrlen;
-#ifdef USE_IPV6
-  unsigned long ipp;
-  struct sockaddr_in6 name6;
-#endif /* USE_IPV6 */
+  socklen_t addrlen;
   struct sockaddr_in name;
 
   if (firewall[0]) {
@@ -664,66 +452,31 @@ int open_address_listen(IP addr, int *port)
            "firewall)");
     return -1;
   }
-#ifdef USE_IPV6
-  if (af_def == AF_INET6) {
-    ipp = getmyip();
-    if(af_def == AF_INET6 && myipv6he != NULL) {
+  if (getmyip() > 0) {
+    sock = getsock(SOCK_LISTEN);
+    if (sock < 1)
+      return -1;
 
-      sock = getsock(SOCK_LISTEN, af_def);
-      bzero((char *) &name6, sizeof(name6));
-      name6.sin6_family = af_def;
-      name6.sin6_port = htons(*port);
-      memcpy(&name6.sin6_addr, &in6addr_any, 16);
-      /* memcpy(&name6.sin6_addr, myipv6he->h_addr, myipv6he->h_length); */
-      if (bind(sock, (struct sockaddr *) &name6, sizeof(name6)) < 0) {
-        killsock(sock);
-        return -1;
-      }
-      addrlen = sizeof(name6);
-      if (getsockname(sock, (struct sockaddr *) &name6, &addrlen) < 0) {
-        killsock(sock);
-        return -1;
-      }
-      *port = ntohs(name6.sin6_port);
-      if (listen(sock, 1) < 0) {
-        killsock(sock);
-        return -1;
-      }
+    egg_bzero((char *) &name, sizeof(struct sockaddr_in));
+    name.sin_family = AF_INET;
+    name.sin_port = htons(*port); /* 0 = just assign us a port */
+    name.sin_addr.s_addr = addr;
+    if (bind(sock, (struct sockaddr *) &name, sizeof(name)) < 0) {
+      killsock(sock);
+      return -1;
     }
-  } else {
-#endif /* USE_IPV6 */
-    if(getmyip() > 0) {
-#ifdef USE_IPV6
-      sock = getsock(SOCK_LISTEN, AF_INET);
-#else
-      sock = getsock(SOCK_LISTEN);
-#endif /* USE_IPV6 */
-      if (sock < 1)
-        return -1;
-
-      egg_bzero((char *) &name, sizeof(struct sockaddr_in));
-      name.sin_family = AF_INET;
-      name.sin_port = htons(*port); /* 0 = just assign us a port */
-      name.sin_addr.s_addr = addr;
-      if (bind(sock, (struct sockaddr *) &name, sizeof(name)) < 0) {
-        killsock(sock);
-        return -1;
-      }
-      /* what port are we on? */
-      addrlen = sizeof(name);
-      if (getsockname(sock, (struct sockaddr *) &name, &addrlen) < 0) {
-        killsock(sock);
-        return -1;
-      }
-      *port = ntohs(name.sin_port);
-      if (listen(sock, 1) < 0) {
-        killsock(sock);
-        return -1;
-      }
+    /* what port are we on? */
+    addrlen = sizeof(name);
+    if (getsockname(sock, (struct sockaddr *) &name, &addrlen) < 0) {
+      killsock(sock);
+      return -1;
+    }
+    *port = ntohs(name.sin_port);
+    if (listen(sock, 1) < 0) {
+      killsock(sock);
+      return -1;
     }
-#ifdef USE_IPV6
   }
-#endif /* USE_IPV6 */
   return sock;
 }
 
@@ -732,24 +485,7 @@ int open_address_listen(IP addr, int *port)
  */
 inline int open_listen(int *port)
 {
-#ifdef USE_IPV6
-  return open_address_listen(myip[0] ? getmyip() : INADDR_ANY, AF_INET, port);
-#else
   return open_address_listen(myip[0] ? getmyip() : INADDR_ANY, port);
-#endif /* USE_IPV6 */
-}
-
-/* Same as above, except this one can be called with an AF_ type
- * the above is being left in for compatibility, and should NOT LONGER BE USED IN THE CORE CODE.
- */
-
-inline int open_listen_by_af(int *port, int af_def)
-{
-#ifdef USE_IPV6
-  return open_address_listen(myip[0] ? getmyip() : INADDR_ANY, af_def, port);
-#else
-  return 0;
-#endif /* USE_IPV6 */
 }
 
 /* Given a network-style IP address, returns the hostname. The hostname
@@ -800,58 +536,27 @@ int answer(int sock, char *caller, unsigned long *ip, unsigned short *port,
            int binary)
 {
   int new_sock;
-  unsigned int addrlen;
+  socklen_t addrlen;
   struct sockaddr_in from;
-#ifdef USE_IPV6
-  int af_ty = getsockproto(sock);
-  struct sockaddr_in6 from6;
 
-  if (af_ty == AF_INET6) {
-    addrlen = sizeof(from6);
-    new_sock = accept(sock, (struct sockaddr *) &from6, &addrlen);
-  } else {
-#endif /* USE_IPV6 */
-    addrlen = sizeof(struct sockaddr);
-    new_sock = accept(sock, (struct sockaddr *) &from, &addrlen);
-#ifdef USE_IPV6
-  }
-#endif /* USE_IPV6 */
+  addrlen = sizeof(struct sockaddr);
+  new_sock = accept(sock, (struct sockaddr *) &from, &addrlen);
 
   if (new_sock < 0)
     return -1;
   if (ip != NULL) {
-#ifdef USE_IPV6
-    if (af_ty == AF_INET6) {
-      *ip = notalloc;
-      egg_inet_ntop(AF_INET6, &from6, caller, 119);
-      caller[120] = 0;
-    } else {
-#endif /* USE_IPV6 */
-      *ip = from.sin_addr.s_addr;
-      /* This is now done asynchronously. We now only provide the IP address.
-       *
-       * strncpy(caller, hostnamefromip(*ip), 120);
-       */
-      strncpyz(caller, iptostr(*ip), 121);
-      *ip = ntohl(*ip);
-#ifdef USE_IPV6
-    }
-#endif /* USE_IPV6 */
+    *ip = from.sin_addr.s_addr;
+    /* This is now done asynchronously. We now only provide the IP address.
+     *
+     * strncpy(caller, hostnamefromip(*ip), 120);
+     */
+    strncpyz(caller, iptostr(*ip), 121);
+    *ip = ntohl(*ip);
   }
-  if (port != NULL) {
-#ifdef USE_IPV6
-      if (af_ty == AF_INET6)
-        *port = ntohs(from6.sin6_port);
-      else
-#endif /* USE_IPV6 */
-        *port = ntohs(from.sin_port);
-    }
+  if (port != NULL)
+    *port = ntohs(from.sin_port);
   /* Set up all the normal socket crap */
-#ifdef USE_IPV6
-  setsock(new_sock, (binary ? SOCK_BINARY : 0), af_ty);
-#else
   setsock(new_sock, (binary ? SOCK_BINARY : 0));
-#endif /* USE_IPV6 */
   return new_sock;
 }
 
@@ -864,40 +569,21 @@ int open_telnet_dcc(int sock, char *server, char *port)
   char sv[500];
   unsigned char c[4];
 
-#ifdef DEBUG_IPV6
-  debug1("open_telnet_dcc %s", server);
-#endif /* DEBUG_IPV6 */
   if (port != NULL)
     p = atoi(port);
   else
     p = 2000;
-#ifdef USE_IPV6
-  if (getprotocol(server) == AF_INET6) {
-#  ifdef DEBUG_IPV6
-    debug0("open_telnet_dcc, af_inet6!");
-#  endif /* DEBUG_IPV6 */
-    strncpyz(sv, server, sizeof sv);
-    debug2("%s should be %s",sv,server);
-  } else {
-#endif /* USE_IPV6 */
-    if (server != NULL)
-      addr = my_atoul(server);
-    else
-      addr = 0L;
-    if (addr < (1 << 24))
-      return -3;                  /* fake address */
-    c[0] = (addr >> 24) & 0xff;
-    c[1] = (addr >> 16) & 0xff;
-    c[2] = (addr >> 8) & 0xff;
-    c[3] = addr & 0xff;
-    sprintf(sv, "%u.%u.%u.%u", c[0], c[1], c[2], c[3]);
-#ifdef USE_IPV6
-    }
-  /* strcpy(sv,hostnamefromip(addr)); */
-#  ifdef DEBUG_IPV6
-  debug3("open_telnet_raw %s %d %d", sv, sock,p);
-#  endif /* DEBUG_IPV6 */
-#endif /* USE_IPV6 */
+  if (server != NULL)
+    addr = my_atoul(server);
+  else
+    addr = 0L;
+  if (addr < (1 << 24))
+    return -3;                  /* fake address */
+  c[0] = (addr >> 24) & 0xff;
+  c[1] = (addr >> 16) & 0xff;
+  c[2] = (addr >> 8) & 0xff;
+  c[3] = addr & 0xff;
+  sprintf(sv, "%u.%u.%u.%u", c[0], c[1], c[2], c[3]);
   p = open_telnet_raw(sock, sv, p);
   return p;
 }
@@ -926,7 +612,7 @@ static int sockread(char *s, int *len)
   t.tv_usec = 0;
   FD_ZERO(&fd);
 
-  for (i = 0; i < MAXSOCKS; i++)
+  for (i = 0; i < MAXSOCKS; i++) {
     if (!(socklist[i].flags & (SOCK_UNUSED | SOCK_VIRTUAL))) {
       if ((socklist[i].sock == STDOUT) && !backgrd)
         fdtmp = STDIN;
@@ -943,15 +629,10 @@ static int sockread(char *s, int *len)
        */
       FD_SET(fdtmp, &fd);
     }
-#ifdef HPUX_HACKS
-#ifndef HPUX10_HACKS
-  x = select(fds, (int *) &fd, (int *) NULL, (int *) NULL, &t);
-#else
-  x = select(fds, &fd, NULL, NULL, &t);
-#endif
-#else
-  x = select(fds, &fd, NULL, NULL, &t);
-#endif
+  }
+  x = select((SELECT_TYPE_ARG1) fds, SELECT_TYPE_ARG234 &fd,
+             SELECT_TYPE_ARG234 NULL, SELECT_TYPE_ARG234 NULL,
+             SELECT_TYPE_ARG5 &t);
   if (x > 0) {
     /* Something happened */
     for (i = 0; i < MAXSOCKS; i++) {
@@ -1236,42 +917,33 @@ void tputs(register int z, char *s, unsigned int len)
   char *p;
   static int inhere = 0;
 
-  if (z < 0)
-    return;                     /* um... HELLO?!  sanity check please! */
+  if (z < 0) /* um... HELLO?! sanity check please! */
+    return;
+
   if (((z == STDOUT) || (z == STDERR)) && (!backgrd || use_stderr)) {
     write(z, s, len);
     return;
   }
+
   for (i = 0; i < MAXSOCKS; i++) {
     if (!(socklist[i].flags & SOCK_UNUSED) && (socklist[i].sock == z)) {
       for (idx = 0; idx < dcc_total; idx++) {
-        if (dcc[idx].sock == z) {
-          if (dcc[idx].type) {
-            if (dcc[idx].type->name) {
-              if (!strncmp(dcc[idx].type->name, "BOT", 3)) {
-                otraffic_bn_today += len;
-                break;
-              } else if (!strcmp(dcc[idx].type->name, "SERVER")) {
-                otraffic_irc_today += len;
-                break;
-              } else if (!strncmp(dcc[idx].type->name, "CHAT", 4)) {
-                otraffic_dcc_today += len;
-                break;
-              } else if (!strncmp(dcc[idx].type->name, "FILES", 5)) {
-                otraffic_filesys_today += len;
-                break;
-              } else if (!strcmp(dcc[idx].type->name, "SEND")) {
-                otraffic_trans_today += len;
-                break;
-              } else if (!strncmp(dcc[idx].type->name, "GET", 3)) {
-                otraffic_trans_today += len;
-                break;
-              } else {
-                otraffic_unknown_today += len;
-                break;
-              }
-            }
-          }
+        if ((dcc[idx].sock == z) && dcc[idx].type && dcc[idx].type->name) {
+          if (!strncmp(dcc[idx].type->name, "BOT", 3))
+            otraffic_bn_today += len;
+          else if (!strcmp(dcc[idx].type->name, "SERVER"))
+            otraffic_irc_today += len;
+          else if (!strncmp(dcc[idx].type->name, "CHAT", 4))
+            otraffic_dcc_today += len;
+          else if (!strncmp(dcc[idx].type->name, "FILES", 5))
+            otraffic_filesys_today += len;
+          else if (!strcmp(dcc[idx].type->name, "SEND"))
+            otraffic_trans_today += len;
+          else if (!strncmp(dcc[idx].type->name, "GET", 3))
+            otraffic_trans_today += len;
+          else
+            otraffic_unknown_today += len;
+          break;
         }
       }
 
@@ -1337,15 +1009,10 @@ void dequeue_sockets()
   }
   if (!z)
     return;                     /* nothing to write */
-#ifdef HPUX_HACKS
-#ifndef HPUX10_HACKS
-  select(fds, (int *) NULL, (int *) &wfds, (int *) NULL, &tv);
-#else
-  select(fds, NULL, &wfds, NULL, &tv);
-#endif
-#else
-  select(fds, NULL, &wfds, NULL, &tv);
-#endif
+
+  select((SELECT_TYPE_ARG1) fds, SELECT_TYPE_ARG234 NULL,
+         SELECT_TYPE_ARG234 &wfds, SELECT_TYPE_ARG234 NULL,
+         SELECT_TYPE_ARG5 &tv);
 
 /* end poptix */
 
@@ -1448,10 +1115,6 @@ int sanitycheck_dcc(char *nick, char *from, char *ipaddy, char *port)
    * DNS names that are up to 255 characters long.  This is not broken.
    */
 
-  /* This function needs to be updated for IPv6 IP's, although it doesn't
-   * currently harm them (afaik)
-   */
-
   char badaddress[16];
   IP ip = my_atoul(ipaddy);
   int prt = atoi(port);
@@ -1460,11 +1123,6 @@ int sanitycheck_dcc(char *nick, char *from, char *ipaddy, char *port)
   if (!dcc_sanitycheck)
     return 1;
 
-#ifdef USE_IPV6
-  if (getprotocol(ipaddy) == AF_INET6)
-    return 1;
-#endif /* USE_IPV6 */
-
   if (prt < 1) {
     putlog(LOG_MISC, "*", "ALERT: (%s!%s) specified an impossible port of %u!",
            nick, from, prt);
