@@ -2,11 +2,11 @@
  * tclmisc.c -- handles:
  *   Tcl stubs for everything else
  *
- * $Id: tclmisc.c,v 1.43 2003/04/17 01:55:57 wcc Exp $
+ * $Id: tclmisc.c,v 1.50 2004/05/26 00:20:19 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,25 +53,6 @@ extern int max_logs;
 extern log_t *logs;
 extern Tcl_Interp *interp;
 
-#ifdef USE_IPV6
-extern char myipv6host[120];
-
-static int tcl_myip6 STDVAR      
-{
-  char s[120];
-
-  getmyip();
-
-  BADARGS(1, 1, "");
-
-  s[0] = 0;
-  if(strlen(myipv6host) < 120)
-    strcpy(s, myipv6host);
-  Tcl_AppendResult(irp, s, NULL);
-  return TCL_OK;
-}
-#endif /* USE_IPV6 */
-
 int expmem_tclmisc()
 {
   int i, tot = 0;
@@ -95,7 +76,7 @@ static int tcl_logfile STDVAR
   char s[151];
 
   BADARGS(1, 4, " ?logModes channel logFile?");
-  
+
   if (argc == 1) {
     /* They just want a list of the logfiles and modes */
     for (i = 0; i < max_logs; i++)
@@ -160,7 +141,7 @@ static int tcl_putlog STDVAR
   char logtext[501];
 
   BADARGS(2, 2, " text");
-  
+
   strncpyz(logtext, argv[1], sizeof logtext);
   putlog(LOG_MISC, "*", "%s", logtext);
   return TCL_OK;
@@ -171,7 +152,7 @@ static int tcl_putcmdlog STDVAR
   char logtext[501];
 
   BADARGS(2, 2, " text");
-  
+
   strncpyz(logtext, argv[1], sizeof logtext);
   putlog(LOG_CMDS, "*", "%s", logtext);
   return TCL_OK;
@@ -182,7 +163,7 @@ static int tcl_putxferlog STDVAR
   char logtext[501];
 
   BADARGS(2, 2, " text");
-  
+
   strncpyz(logtext, argv[1], sizeof logtext);
   putlog(LOG_FILES, "*", "%s", logtext);
   return TCL_OK;
@@ -194,7 +175,7 @@ static int tcl_putloglev STDVAR
   char logtext[501];
 
   BADARGS(4, 4, " level channel text");
-  
+
   lev = logmodes(argv[1]);
   if (!lev) {
     Tcl_AppendResult(irp, "No valid log-level given", NULL);
@@ -309,7 +290,7 @@ static int tcl_killtimer STDVAR
 static int tcl_killutimer STDVAR
 {
   BADARGS(2, 2, " timerID");
-  
+
   if (strncmp(argv[1], "timer", 5)) {
     Tcl_AppendResult(irp, "argument is not a timerID", NULL);
     return TCL_ERROR;
@@ -379,6 +360,8 @@ static int tcl_duration STDVAR
     tmp = (sec);
     sprintf(&s[strlen(s)], "%lu second%s", tmp, (tmp == 1) ? "" : "s");
   }
+  if (strlen(s) > 0 && s[strlen(s) - 1] == ' ')
+    s[strlen(s) - 1] = 0;
   Tcl_AppendResult(irp, s, NULL);
   return TCL_OK;
 }
@@ -389,7 +372,7 @@ static int tcl_unixtime STDVAR
   time_t now2 = time(NULL);
 
   BADARGS(1, 1, "");
-  
+
   egg_snprintf(s, sizeof s, "%lu", (unsigned long) now2);
   Tcl_AppendResult(irp, s, NULL);
   return TCL_OK;
@@ -401,7 +384,7 @@ static int tcl_ctime STDVAR
   char s[25];
 
   BADARGS(2, 2, " unixtime");
-  
+
   tt = (time_t) atol(argv[1]);
   strncpyz(s, ctime(&tt), sizeof s);
   Tcl_AppendResult(irp, s, NULL);
@@ -434,7 +417,7 @@ static int tcl_myip STDVAR
   char s[16];
 
   BADARGS(1, 1, "");
-   
+
   egg_snprintf(s, sizeof s, "%lu", iptolong(getmyip()));
   Tcl_AppendResult(irp, s, NULL);
   return TCL_OK;
@@ -451,7 +434,8 @@ static int tcl_rand STDVAR
     Tcl_AppendResult(irp, "random limit must be greater than zero", NULL);
     return TCL_ERROR;
   }
-   x = random() % (unsigned long) (atol(argv[1]));
+
+  x = randint((unsigned long) (atol(argv[1])));
 
   egg_snprintf(s, sizeof s, "%lu", x);
   Tcl_AppendResult(irp, s, NULL);
@@ -463,7 +447,7 @@ static int tcl_sendnote STDVAR
   char s[5], from[NOTENAMELEN + 1], to[NOTENAMELEN + 1], msg[451];
 
   BADARGS(4, 4, " from to message");
-  
+
   strncpyz(from, argv[1], sizeof from);
   strncpyz(to, argv[2], sizeof to);
   strncpyz(msg, argv[3], sizeof msg);
@@ -478,7 +462,7 @@ static int tcl_dumpfile STDVAR
   struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   BADARGS(3, 3, " nickname filename");
- 
+
   strncpyz(nick, argv[1], sizeof nick);
   get_user_flagrec(get_user_by_nick(nick), &fr, NULL);
   showhelp(argv[1], argv[2], &fr, HELP_TEXT);
@@ -491,7 +475,7 @@ static int tcl_dccdumpfile STDVAR
   struct flag_record fr = { FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0 };
 
   BADARGS(3, 3, " idx filename");
- 
+
   i = atoi(argv[1]);
   idx = findidx(i);
   if (idx < 0) {
@@ -632,7 +616,7 @@ static int tcl_reloadhelp STDVAR
 static int tcl_callevent STDVAR
 {
   BADARGS(2, 2, " event");
-  
+
   check_tcl_event(argv[1]);
   return TCL_OK;
 }
@@ -647,7 +631,7 @@ Tcl_Obj *CONST objv[];
 #else
 static int tcl_md5 STDVAR
 {
-#endif				/* USE_TCL_OBJ */
+#endif /* USE_TCL_OBJ */
   MD5_CTX md5context;
   char digest_string[33], *string;
   unsigned char digest[16];
@@ -659,13 +643,13 @@ static int tcl_md5 STDVAR
     return TCL_ERROR;
   }
 #  ifdef USE_TCL_BYTE_ARRAYS
-  string = Tcl_GetByteArrayFromObj(objv[1], &len);
+  string = (unsigned char *)Tcl_GetByteArrayFromObj(objv[1], &len);
 #  else
   string = Tcl_GetStringFromObj(objv[1], &len);
 #  endif /* USE_TCL_BYTE_ARRAYS */
 #else /* USE_TCL_OBJ */
   BADARGS(2, 2, " string");
-  
+
   string = argv[1];
   len = strlen(argv[1]);
 #endif /* USE_TCL_OBJ */
@@ -702,9 +686,6 @@ tcl_cmds tclmisc_cmds[] = {
   {"strftime",         tcl_strftime},
   {"ctime",               tcl_ctime},
   {"myip",                 tcl_myip},
-#ifdef USE_IPV6
-  {"myip6",               tcl_myip6},
-#endif /* USE_IPV6 */
   {"rand",                 tcl_rand},
   {"sendnote",         tcl_sendnote},
   {"dumpfile",         tcl_dumpfile},
